.. _model_selection:

Model selection and evaluation
------------------------------

.. toctree::
    :maxdepth: 2

    modules/cross_validation
    modules/grid_search
    modules/classification_threshold
    modules/model_evaluation
    modules/learning_curve
